@@ -1,7 +1,7 @@
 from pathlib import Path
 
 __software__ = "fbc_curation"
-__version__ = "0.1.3"
+__version__ = "0.1.6"
 __citation__ = "https://doi.org/10.5281/zenodo.3708271"
 
-EXAMPLE_PATH = Path(__file__).parent.parent.parent / "examples"
+EXAMPLE_PATH = Path(__file__).parent / "examples"
